==> jaxrs-ri-2.4.1-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/RuntimeExecutorsBinder.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal;

import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.glassfish.jersey.spi.RuntimeThreadProvider;

import org.glassfish.hk2.api.AnnotationLiteral;
import org.glassfish.hk2.api.Factory;
import org.glassfish.hk2.utilities.binding.AbstractBinder;

import org.jvnet.hk2.annotations.Optional;

import com.google.common.util.concurrent.ThreadFactoryBuilder;

/**
 * Binder for injectable Jersey runtime executor services.
 *
 * Presently it implements a binding  for a {@link BackgroundScheduler background scheduler} singleton
 * executor service.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
public class RuntimeExecutorsBinder extends AbstractBinder {
    private static class BackgroundSchedulerFactory implements Factory<ScheduledExecutorService> {
        private final RuntimeThreadProvider runtimeThreadProvider;

        @Inject
        public BackgroundSchedulerFactory(@Optional RuntimeThreadProvider rtp) {
            if (rtp == null) {
                rtp = new RuntimeThreadProvider() {
                    @Override
                    public ThreadFactory getRequestThreadFactory() {
                        return new ThreadFactoryBuilder()
                                .setNameFormat("jersey-request-specific-task-thread-%d")
                                .build();
                    }

                    @Override
                    public ThreadFactory getBackgroundThreadFactory() {
                        return new ThreadFactoryBuilder()
                                .setNameFormat("jersey-background-task-thread-%d")
                                .build();
                    }
                };
            }

            this.runtimeThreadProvider = rtp;
        }

        @Override
        public ScheduledExecutorService provide() {
            final ThreadFactory threadFactory = new ThreadFactoryBuilder()
                    .setNameFormat("jersey-background-task-scheduler-%d")
                    .setThreadFactory(runtimeThreadProvider.getBackgroundThreadFactory())
                    .build();

            return new ScheduledThreadPoolExecutor(1, threadFactory, new RejectedExecutionHandler() {
                @Override
                public void rejectedExecution(Runnable r, ThreadPoolExecutor executor) {
                    // TODO: implement method.
                }
            });
        }

        @Override
        public void dispose(ScheduledExecutorService instance) {
            instance.shutdown();
        }
    }

    /**
     * {@link AnnotationLiteral Annotation literal} helper class for the
     * {@link BackgroundScheduler &#64;BackgroundScheduler} qualifier annotation.
     */
    @SuppressWarnings("ClassExplicitlyAnnotation")
    public static class BackgroundSchedulerLiteral
            extends AnnotationLiteral<BackgroundScheduler> implements BackgroundScheduler {
    }

    @Override
    protected void configure() {
        bindFactory(BackgroundSchedulerFactory.class)
                .to(ScheduledExecutorService.class)
                .qualifiedBy(new BackgroundSchedulerLiteral())
                .in(Singleton.class);
    }
}

==> jaxrs-ri-2.9-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/RuntimeExecutorsBinder.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal;

import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.glassfish.jersey.spi.RuntimeThreadProvider;

import org.glassfish.hk2.api.AnnotationLiteral;
import org.glassfish.hk2.api.Factory;
import org.glassfish.hk2.utilities.binding.AbstractBinder;

import org.jvnet.hk2.annotations.Optional;

import jersey.repackaged.com.google.common.util.concurrent.ThreadFactoryBuilder;

/**
 * Binder for injectable Jersey runtime executor services.
 *
 * Presently it implements a binding  for a {@link BackgroundScheduler background scheduler} singleton
 * executor service.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
public class RuntimeExecutorsBinder extends AbstractBinder {
    private static class BackgroundSchedulerFactory implements Factory<ScheduledExecutorService> {
        private final RuntimeThreadProvider runtimeThreadProvider;

        @Inject
        public BackgroundSchedulerFactory(@Optional RuntimeThreadProvider rtp) {
            if (rtp == null) {
                rtp = new RuntimeThreadProvider() {
                    @Override
                    public ThreadFactory getRequestThreadFactory() {
                        return new ThreadFactoryBuilder()
                                .setNameFormat("jersey-request-specific-task-thread-%d")
                                .build();
                    }

                    @Override
                    public ThreadFactory getBackgroundThreadFactory() {
                        return new ThreadFactoryBuilder()
                                .setNameFormat("jersey-background-task-thread-%d")
                                .build();
                    }
                };
            }

            this.runtimeThreadProvider = rtp;
        }

        @Override
        public ScheduledExecutorService provide() {
            final ThreadFactory threadFactory = new ThreadFactoryBuilder()
                    .setNameFormat("jersey-background-task-scheduler-%d")
                    .setThreadFactory(runtimeThreadProvider.getBackgroundThreadFactory())
                    .build();

            return new ScheduledThreadPoolExecutor(1, threadFactory, new RejectedExecutionHandler() {
                @Override
                public void rejectedExecution(Runnable r, ThreadPoolExecutor executor) {
                    // TODO: implement method.
                }
            });
        }

        @Override
        public void dispose(ScheduledExecutorService instance) {
            instance.shutdown();
        }
    }

    /**
     * {@link AnnotationLiteral Annotation literal} helper class for the
     * {@link BackgroundScheduler &#64;BackgroundScheduler} qualifier annotation.
     */
    @SuppressWarnings("ClassExplicitlyAnnotation")
    public static class BackgroundSchedulerLiteral
            extends AnnotationLiteral<BackgroundScheduler> implements BackgroundScheduler {
    }

    @Override
    protected void configure() {
        bindFactory(BackgroundSchedulerFactory.class)
                .to(ScheduledExecutorService.class)
                .qualifiedBy(new BackgroundSchedulerLiteral())
                .in(Singleton.class);
    }
}
